==> 0.13.0.tar.gz: example/lib/configs/locales/locale_zh_hans.dart <==
Map<String, String> localeZhHans = {
  // common
  'common.locale_name_ja': '日语',
  'common.locale_name_zh_CN': '简体中文',

  // not_found_page
  'not_found_page.title': '找不到该页',
  'not_found_page.content': '抱歉，找不到该页！',

  // http
  'http.errorMessage': 'HTTP请求失败（@statusCode）：@errorMessage',
  'http.ParamaterInvalid': '无效参数',
  'http.Unauthorized': '密钥不存在、错误或过期',
  'http.AccountPasswordInvalid': '无效账号或密码',
  'http.AccountLocked': '账号已锁定',
  'http.AccountOffline': '账号已离线',
  'http.Forbidden': '未授权对该资源的操作',
  'http.Existing': '资料已存在，无法进行操作',
  'http.NotFound': '资料不存在',
  'http.MethodNotAllowed': '不允许使用该方法',
  'http.ServerError': '服务器内部错误',
  'http.Unknown': '未知错误，可能是网络不稳定',

  // main_page
  'main_page.home': '首页',
  'main_page.home_title': 'Flutter Waff Example',
  'main_page.widget_example': '组件',
  'main_page.widget_example_title': '组件演示',
  'main_page.utils_example': '工具',
  'main_page.utils_example_title': '工具演示',
  'main_page.locale_theme_example': '国际化&主题',
  'main_page.locale_theme_example_title': '国际化&主题演示',
  'main_page.documents': '开发文档',

  // home_page
  'home_page.title': '关于 waff',
  'home_page.intro':
      '''泛用Flutter轻框架（英文：Wide App Flutter light-Framework，以下简称Waff）是针对Android/iOS快速开发，自主设计封装的一套横向分层、纵向模块驱动、快速实现业务逻辑的Flutter轻框架；无需区分Android/iOS，轻松实现一次开发多端发布。

Waff基于Flutter2+GetX将工程结构、开发方式、业务逻辑实现等进行了高度标准化。常用功能及组件分层封装，结合开发文档及例程，让开发者在项目初期快速搭建App开发骨架，达成代码实现的共识，专注业务逻辑开发。

Waff是文思海辉BG9产业WF交付中心基于Site小黑板App开发过程，萃取了工程结构，开发方式及业务逻辑实现，结合以前或参与过的Android/iOS各项目优秀特性，抽象设计封装的Flutter轻框架，可同时为Android/iOS的App开发提供项目构建、培训及开发实施等。已初步形成框架迭代、更新升级的规则机制，为Waff持续完善、迭代保驾护行。''',

  // locale_theme_example_page
  'locale_theme_example_page.change_theme_mode': '更改主题模式 (当前:@mode)',
  'locale_theme_example_page.theme_mode_light': '亮色',
  'locale_theme_example_page.theme_mode_dark': '暗色',
  'locale_theme_example_page.theme_mode_system': '跟随系统',
  'locale_theme_example_page.change_locale': '更改语言 (当前:@localeName)',
  'locale_theme_example_page.hello': '你好！',
  'locale_theme_example_page.hello_name': '你好！@name',
  'locale_theme_example_page.theme_colors':
      '无法通过ThemeData定义的颜色，请在theme_colors.dart中定义',

  // utils_example_page
  'utils_example_page.eventBus': '全局消息',
  'utils_example_page.appLifecycle': 'App 生命周期',
  'utils_example_page.connectivity': '网络状态',

  // app_lifecycle_page
  'app_lifecycle_page.title': 'App 生命周期演示',
  'app_lifecycle_page.intro':
      '使用方式：\n1、在 start_app.dart 或任意位置使用 AppLifecycleListener.startup 启动，这是单件模式\n2、通过 Controller 监听\n\n本实例会在控制台输出Log信息',

  // connectivity_page
  'connectivity_page.title': '网络状态演示',
  'connectivity_page.intro':
      '当前状态：@state\n\n使用方式：\n1、在任意位置使用 ConnectivityListener.startup 启动，这是单件模式\n2、通过 Controller 监听\n\nConnectivityState 包含 WIFI, WIFI_AVAILABLE, WIFI_NOT_AVAILABLE, MOBILE, MOBILE_AVAILABLE, MOBILE_NOT_AVAILABLE, NONE 7种状态',

  // event_bus_page
  'event_bus_page.title': '全局事件(EventBus)演示',
  'event_bus_page.intro':
      '在 [services/event_bus_events.dart] 中定义消息事件，以下是 [ExampleEvent] 事件的使用案例。',
  'event_bus_page.send_message': '发送事件',
  'event_bus_page.receive_message': '接收到的事件内容：@message',
  'event_bus_page.non_message': '暂无事件',
};

==> 2.0.0.tar.gz: example/lib/configs/locales/locale_zh_hans.dart <==
Map<String, String> localeZhHans = {
  // common
  'common.locale_name_ja': '日语',
  'common.locale_name_zh_CN': '简体中文',

  // not_found_page
  'not_found_page.title': '找不到该页',
  'not_found_page.content': '抱歉，找不到该页！',

  // http
  'http.errorMessage': 'HTTP请求失败（@statusCode）：@errorMessage',
  'http.ParamaterInvalid': '无效参数',
  'http.Unauthorized': '密钥不存在、错误或过期',
  'http.AccountPasswordInvalid': '无效账号或密码',
  'http.AccountLocked': '账号已锁定',
  'http.AccountOffline': '账号已离线',
  'http.Forbidden': '未授权对该资源的操作',
  'http.Existing': '资料已存在，无法进行操作',
  'http.NotFound': '资料不存在',
  'http.MethodNotAllowed': '不允许使用该方法',
  'http.ServerError': '服务器内部错误',
  'http.UnknownError': '未知错误，可能是网络不稳定',

  // main_page
  'main_page.home': '首页',
  'main_page.home_title': 'Flutter Waff Example',
  'main_page.widget_example': '组件',
  'main_page.widget_example_title': '组件演示',
  'main_page.utils_example': '工具',
  'main_page.utils_example_title': '工具演示',
  'main_page.locale_theme_example': '国际化&主题',
  'main_page.locale_theme_example_title': '国际化&主题演示',
  'main_page.documents': '开发文档',

  // home_page
  'home_page.title': '关于 waff',
  'home_page.intro':
      '''泛用Flutter轻框架（英文：Wide App Flutter light-Framework，以下简称Waff）是针对Android/iOS快速开发，自主设计封装的一套横向分层、纵向模块驱动、快速实现业务逻辑的Flutter轻框架；无需区分Android/iOS，轻松实现一次开发多端发布。

Waff基于Flutter2+GetX将工程结构、开发方式、业务逻辑实现等进行了高度标准化。常用功能及组件分层封装，结合开发文档及例程，让开发者在项目初期快速搭建App开发骨架，达成代码实现的共识，专注业务逻辑开发。

Waff是文思海辉BG9产业WF交付中心基于Site小黑板App开发过程，萃取了工程结构，开发方式及业务逻辑实现，结合以前或参与过的Android/iOS各项目优秀特性，抽象设计封装的Flutter轻框架，可同时为Android/iOS的App开发提供项目构建、培训及开发实施等。已初步形成框架迭代、更新升级的规则机制，为Waff持续完善、迭代保驾护行。''',

  // locale_theme_example_page
  'locale_theme_example_page.change_theme_mode': '更改主题模式 (当前:@mode)',
  'locale_theme_example_page.theme_mode_light': '亮色',
  'locale_theme_example_page.theme_mode_dark': '暗色',
  'locale_theme_example_page.theme_mode_system': '跟随系统',
  'locale_theme_example_page.change_locale': '更改语言 (当前:@localeName)',
  'locale_theme_example_page.hello': '你好！',
  'locale_theme_example_page.hello_name': '你好！@name',
  'locale_theme_example_page.theme_colors':
      '无法通过ThemeData定义的颜色，请在theme_colors.dart中定义',

  // utils_example_page
  'utils_example_page.eventBus': '全局消息',
  'utils_example_page.appLifecycle': 'App 生命周期',
  'utils_example_page.connectivity': '网络状态',

  // app_lifecycle_page
  'app_lifecycle_page.title': 'App 生命周期演示',
  'app_lifecycle_page.intro':
      '使用方式：\n1、在 start_app.dart 或任意位置使用 AppLifecycleListener.startup 启动，这是单件模式\n2、通过 Controller 监听\n\n本实例会在控制台输出Log信息',

  // connectivity_page
  'connectivity_page.title': '网络状态演示',
  'connectivity_page.intro':
      '当前状态：@state\n\n使用方式：\n1、在任意位置使用 ConnectivityListener.startup 启动，这是单件模式\n2、通过 Controller 监听\n\nConnectivityState 包含：\nBLUETOOTH、BLUETOOTH_AVAILABLE、BLUETOOTH_NOT_AVAILABLE、WIFI、WIFI_AVAILABLE、WIFI_NOT_AVAILABLE、ETHERNET、ETHERNET_AVAILABLE、ETHERNET_NOT_AVAILABLE、MOBILE、MOBILE_AVAILABLE、MOBILE_NOT_AVAILABLE、NONE',

  // event_bus_page
  'event_bus_page.title': '全局事件(EventBus)演示',
  'event_bus_page.intro':
      '在 [services/event_bus_events.dart] 中定义消息事件，以下是 [ExampleEvent] 事件的使用案例。',
  'event_bus_page.send_message': '发送事件',
  'event_bus_page.receive_message': '接收到的事件内容：@message',
  'event_bus_page.non_message': '暂无事件',
};
